#! /usr/bin/env python3
#
# Deploy Radiostations for Zynthian's iNetRadio PD-patch
#
# Arguments:
#   accepts one argument: radio-stations file (default = radiostations.txt)
#
# reads radio-station names and stream-urls from radiostations.txt
# unused radio-station slots will be set to "Off"
# reads main.pd.template, inserts stream-urls and write out to main.pd
# reads zynconfig.yml.template, inserts station names and write out to zynconfig.yml
#
# ATTENTION:  The files main.pd and zynconfig.yml will get overwritten!
#             This script does no error-checking! 
#
#
# script revision: 2024-02-01


import sys
import string

# default name of the file containing radio-station names and stream-urls
stations_filename = 'radiostations.txt'

# how many slots for radio stations are in main.pd.template?
max_stations = 22

# Process command line arguments
if len(sys.argv) == 2:
    stations_filename = sys.argv[1]
elif len(sys.argv) > 2:
    print("Too many arguments!")
    sys.exit(1)

# Open the radiostations file
try:
    stations_file = open(stations_filename, 'r')
except Exception as exc:
    print("Radio-stations file: " + str(exc))
    sys.exit(1)

# Read in the main.pd.template file
try:
    with open('main.pd.template', 'r') as mainpd_file:
        mainpd_data = mainpd_file.read()
except Exception as exc:
    print(str(exc))
    sys.exit(1)

# Read in the zynconfig.yml.template file
try:
    with open('zynconfig.yml.template', 'r') as config_file:
        config_data = config_file.read()
except Exception as exc:
    print(str(exc))
    sys.exit(1)

# Deploy the radio stations to the PD-patch and the zynconfig file
for i in range(max_stations):
    station_name = stations_file.readline()
    # skip blank lines and remark lines (but prevent an endless loop at EOF)  
    while (station_name != "" and station_name.strip() == "") or station_name[:1] == "#":
        station_name = stations_file.readline()
    station_url = stations_file.readline()
    # skip remark lines
    while station_url[:1] == "#":
        station_url = stations_file.readline()
    station_name = station_name.strip()
    station_url = station_url.strip()
    if not station_url or station_url[:1] == "#":
        station_name = "Off"
        station_url = "Off"

    # Replace the target strings
    config_data = config_data.replace('NAME#'+str(i).zfill(2), station_name)
    mainpd_data = mainpd_data.replace('STREAM#'+str(i).zfill(2), station_url)

    # Print a list of the configured radio-stations
    print(str(i+1) + ': ' + station_name + ' -> ' + station_url)

# Write the files out
try:
    with open('main.pd', 'w') as file:
      file.write(mainpd_data)
    with open('zynconfig.yml', 'w') as file:
      file.write(config_data)
except Exception as exc:
    print(str(exc))


